@@ -43,8 +43,11 @@ def build_dataloader(dataset: Dataset,
                                                              rank=comm.get_local_rank(),
                                                              shuffle=shuffle)
         shuffle = False  # sampler option is mutually exclusive with shuffle
+    else:
+        # Fix a Bug: RuntimeError: can't start new thread
+        persistent_workers = False
     try:
-        # fix a bug: torch<=1.6 have no argument 'persistent_workers'
+        # Fix a Bug: torch<=1.6 have no argument 'persistent_workers'
         if get_torch_version() >= 1.7:
             kwargs["persistent_workers"] = persistent_workers
             # fix a bug: persistent_workers option needs num_workers > 0
